library ftx;

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

extension StringExtension on String{
  Text get text => Text(this);
}

class BoxBuilder {
  final Widget _widget;
  double _radius=0;
  Color _color = Colors.transparent;
  double _paddingLeft=0,_paddingRight=0,_paddingTop=0,_paddingBottom=0;

  BoxBuilder rounded(double radius){
    this._radius=radius;
    return this;
  }

  BoxBuilder p(double padding){
    this._paddingLeft=padding;
    this._paddingRight=padding;
    this._paddingTop=padding;
    this._paddingBottom=padding;
    return this;
  }

  BoxBuilder px(double padding){
    this._paddingLeft=padding;
    this._paddingRight=padding;
    return this;
  }

  BoxBuilder py(double padding){
    this._paddingTop=padding;
    this._paddingBottom=padding;
    return this;
  }
  BoxBuilder pl(double padding){
    this._paddingLeft=padding;
    return this;
  }
  BoxBuilder pr(double padding){
    this._paddingRight=padding;
    return this;
  }
  BoxBuilder pt(double padding){
    this._paddingTop=padding;
    return this;
  }
  BoxBuilder pb(double padding){
    this._paddingBottom=padding;
    return this;
  }

  BoxBuilder color(Color color){
    this._color=color;
    return this;
  }

  Container build(){
    return Container(
      padding: EdgeInsets.only(left: _paddingLeft,right: _paddingRight,top: _paddingTop,bottom: _paddingBottom),
      decoration: BoxDecoration(
        color: _color,
        borderRadius: BorderRadius.circular(_radius)
      ),
      child: _widget,
    );
  }

  BoxBuilder(this._widget);
}


extension CommonExtension on Widget {

  BoxBuilder get box => BoxBuilder(this);

  Widget onTap(Function onTap){
    return GestureDetector(
      onTap: onTap,
      child: this,
    );
  }

  DecoratedBox asBox({
    Color color,
    BoxBorder border,
    BorderRadiusGeometry borderRadius,
    List<BoxShadow> boxShadow,
    Gradient gradient,
  }) => DecoratedBox(decoration: BoxDecoration(
      color: color,
      borderRadius: borderRadius,
      boxShadow: boxShadow,
      gradient: gradient

  ),child: this,);

}

extension RoundedExtension on Widget {
  Widget asContainer()=> Container(child: this,);

}


extension AlignExtension on Widget{
  Widget align(Alignment alignment){
    return Align(
      alignment: alignment,
      child: this,
    );
  }
  Widget alignCenter(){
    return Align(
      alignment: Alignment.center,
      child: this,
    );
  }
  Widget alignTopRight(){
    return Align(
      alignment: Alignment.topRight,
      child: this,
    );
  }
  Widget alignTopLeft(){
    return Align(
      alignment: Alignment.topLeft,
      child: this,
    );
  }
  Widget alignTopCenter(){
    return Align(
      alignment: Alignment.topCenter,
      child: this,
    );
  }
  Widget alignBottomRight(){
    return Align(
      alignment: Alignment.bottomRight,
      child: this,
    );
  }
  Widget alignBottomLeft(){
    return Align(
      alignment: Alignment.bottomLeft,
      child: this,
    );
  }
  Widget alignBottomCenter(){
    return Align(
      alignment: Alignment.bottomCenter,
      child: this,
    );
  }
  Widget alignCenterLeft(){
    return Align(
      alignment: Alignment.centerLeft,
      child: this,
    );
  }
  Widget alignCenterRight(){
    return Align(
      alignment: Alignment.centerRight,
      child: this,
    );
  }
}

extension PaddingExtension on Widget{
  Widget p(double padding){
    return Padding(
      padding: EdgeInsets.all(padding),
      child: this,
    );
  }
  Widget px(double horizontalPadding){
    return Padding(
      padding: EdgeInsets.only(left:horizontalPadding,right: horizontalPadding),
      child: this,
    );
  }
  Widget py(double verticalPadding){
    return Padding(
      padding: EdgeInsets.only(top:verticalPadding,bottom: verticalPadding),
      child: this,
    );
  }
  Widget pt(double topPadding){
    return Padding(
      padding: EdgeInsets.only(top:topPadding),
      child: this,
    );
  }
  Widget pb(double bottomPadding){
    return Padding(
      padding: EdgeInsets.only(bottom:bottomPadding),
      child: this,
    );
  }
  Widget pl(double leftPadding){
    return Padding(
      padding: EdgeInsets.only(left:leftPadding),
      child: this,
    );
  }
  Widget pr(double rightPadding){
    return Padding(
      padding: EdgeInsets.only(right:rightPadding),
      child: this,
    );
  }
}
